__v0.0.7.4 - 2017-03-07__  
Add JSON-LD (http://json-ld.org/) metadata for improved SEO 

__v0.0.7.3 - 2017-03-05__  
Add category links to sitemap  
Automatically generate sitemap when editing posts and categories  
Add AMP (Accelerated Mobile Pages)  

__v0.0.7.2 - 2017-03-02__  
Fix JS with Admin editing not saving textarea fields

__v0.0.7.1 - 2017-02-26__  
Fix sitemap generation bug for last modified date

__v0.0.7.0 - 2017-02-26__  
Add sitemap generation

__v0.0.6.4 - 2017-02-26__  
Fix bug with editing selected category

__v0.0.6.3 - 2017-02-26__  
Add migration support    
Enable multiple rich editable fields per page  
Add new summary column 

__v0.0.6.2 - 2017-02-25__  
Fix head partial import bug  
Fix textarea editing in admin forms

__v0.0.6.1 - 2017-02-24__  
Fix macros import bug 

__v0.0.6 - 2017-02-23__  
Add CSS templates / theming  

__v0.0.5 - 2016-12-28__  
Add unit tests  
Add rich text editor

__v0.0.4 - 2016-12-26__  
Update packaging

__v0.0.3 - 2016-12-26__  
Update packaging

__v0.0.2 - 2016-12-26__  
Update documentation

__v0.0.1 - 2016-12-26__  
Initial import